@@ -1,8 +1,18 @@
+#ifndef __NR_io_setup
 #define __NR_io_setup		206
+#endif
+#ifndef __NR_io_destroy
 #define __NR_io_destroy		207
+#endif
+#ifndef __NR_io_getevents
 #define __NR_io_getevents	208
+#endif
+#ifndef __NR_io_submit
 #define __NR_io_submit		209
+#endif
+#ifndef __NR_io_cancel
 #define __NR_io_cancel		210
+#endif
 
 #define __syscall_clobber "r11","rcx","memory" 
 #define __syscall "syscall"
@@ -42,10 +52,11 @@ return __res;								\
 type fname (type1 arg1, type2 arg2, type3 arg3, type4 arg4)		\
 {									\
 long __res;								\
-__asm__ volatile ("movq %5,%%r10 ;" __syscall				\
+register long __a4 asm ("r10") = (long) arg4;                           \
+__asm__ volatile (__syscall						\
 	: "=a" (__res)							\
 	: "0" (__NR_##sname),"D" ((long)(arg1)),"S" ((long)(arg2)),	\
-	  "d" ((long)(arg3)),"g" ((long)(arg4)) : __syscall_clobber,"r10" ); \
+	  "d" ((long)(arg3)),"r" (__a4)); \
 return __res;								\
 } 
 
@@ -54,10 +65,11 @@ return __res;								\
 type fname (type1 arg1,type2 arg2,type3 arg3,type4 arg4,type5 arg5)	\
 {									\
 long __res;								\
-__asm__ volatile ("movq %5,%%r10 ; movq %6,%%r8 ; " __syscall		\
+register long __a4 asm ("r10") = (long) arg4;				\
+register long __a5 asm ("r8") = (long) arg5;                            \
+__asm__ volatile (__syscall						\
 	: "=a" (__res)							\
 	: "0" (__NR_##sname),"D" ((long)(arg1)),"S" ((long)(arg2)),	\
-	  "d" ((long)(arg3)),"g" ((long)(arg4)),"g" ((long)(arg5)) :	\
-	__syscall_clobber,"r8","r10" );					\
+	  "d" ((long)(arg3)),"r" (__a4),"r" (__a5)); \
 return __res;								\
 }
